@@ -4,14 +4,18 @@
 #' Useful if your optimization is likely to crash,
 #' so you can continue from a save point and will not lose too much information and runtime.
 #'
-#' @param file [\code{character(1)}]\cr
-#'   File path of saved MBO state.
+#' @param opt.state [\code{OptState} | \code{character(1)}]\cr
+#'   Either the \code{save.state} slot of an \code{MBOResult} object, or a file path of a saved MBO state.
 #'   See \code{save.on.disk.at} argument of \code{\link{MBOControl}} object.
 #' @return See \code{\link{mbo}}.
 #' @export
-mboContinue = function(file) {
-  assertCharacter(file, len = 1L)
-  opt.state = loadOptState(file)
+mboContinue = function(opt.state) {
+  if (checkCharacter(opt.state, len = 1L)) {
+    opt.state = loadOptState(opt.state)
+  }
+  if (!inherits(opt.state, "OptState")) {
+    stop("opt.state must be either an OptState object, or a file path of a saved OptState.")
+  }
   state = getOptStateState(opt.state)
   if (state %nin% c("init", "iter")) {
     warningf("Tuning ended with %s. No need to continue. Simply returning stored result.", state)
